@@ -604,16 +604,37 @@ def menu_uninstall():
 # Click CLI commands
 @click.group(invoke_without_command=True)
 @click.option("--version", "-v", is_flag=True, help="Show version")
+@click.option("--classic", is_flag=True, help="Use classic menu instead of TUI")
 @click.pass_context
-def main(ctx, version):
+def main(ctx, version, classic):
     """DarkCode Server - Remote Claude Code from your phone."""
     if version:
         console.print(f"darkcode-server v{__version__}")
         return
 
     if ctx.invoked_subcommand is None:
-        # No subcommand - show interactive menu
-        interactive_menu()
+        if classic:
+            # Use old menu if explicitly requested
+            interactive_menu()
+        else:
+            # Default to modern TUI with arrow key navigation
+            try:
+                from darkcode_server.tui import run_tui
+                result = run_tui()
+                if result:
+                    action, mode = result
+                    if action == "start":
+                        # Start server with selected mode
+                        config = ServerConfig.load()
+                        if mode == "ssh":
+                            config.local_only = True
+                        else:
+                            config.local_only = False
+                        # Call the start command logic
+                        ctx.invoke(start, local_only=config.local_only)
+            except ImportError:
+                console.print("[yellow]TUI requires textual. Falling back to classic menu.[/]")
+                interactive_menu()
 
 
 @main.command()
